.. Segway documentation master file, created by
   sphinx-quickstart on Thu Apr 16 15:13:23 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Segway |version| Documentation
==============================

:Homepage: http://pmgenomics.ca/hoffmanlab/proj/segway
:Author: Michael M. Hoffman <michael dot hoffman at utoronto dot ca>
:Organization: Princess Margaret Cancer Centre
:Address: Toronto Medical Discovery Tower 11-311, 101 College St, M5G 1L7, Toronto, Ontario, Canada
:Copyright: 2009-2015 Michael M. Hoffman
:Last updated: |today|

.. currentmodule:: segway

.. include:: <isonum.txt>

For a conceptual overview see the paper:

  Michael M. Hoffman, Orion J. Buske, Zhiping Weng, Jeff A. Bilmes,
  William Stafford Noble. 2012.
  `Unsupervised pattern discovery in human chromatin structure through genomic
  segmentation
  <http://www.nature.com/nmeth/journal/v9/n5/full/nmeth.1937.html>`_.
  *Nat Methods* 9:473-476.
  `doi:10.1038/nmeth.1937 <http://dx.doi.org/10.1038/nmeth.1937>`_.

`Manuscript version
<http://www.ncbi.nlm.nih.gov/pmc/articles/PMC3340533/>`_ available at
PubMed Central requires no subscription.

For a preprint of a protocol on using Segway see:

  Roberts EG, Mendez M, Viner C, Karimzadeh M, Chan RCW, Ancar R, Chicco D,
  Hesselberth JR, Kundaje A, Hoffman MM. 2016.
  `Semi-automated genome annotation using epigenomic data and
  Segway
  <http://doi.org/10.1101/080382>`_.
  Preprint: `<http://doi.org/10.1101/080382>`_


.. toctree::
   :maxdepth: 2

   quick
   segway
   technical
   faq
   troubleshooting
   support

.. Currently all empty
.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
..
